==> haskell-lucid-2.9.10-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lucid
version: 2.9.10
id: lucid-2.9.10-Lw86LtstYuwAdYyVyAbwQe
key: lucid-2.9.10-Lw86LtstYuwAdYyVyAbwQe
license: BSD-3-Clause
copyright: 2014-2017 Chris Done
maintainer: chrisdone@gmail.com, oleg.grenrus@iki.fi
author: Chris Done
homepage: https://github.com/chrisdone/lucid
synopsis: Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.
    .
    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)
    .
    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')
    .
    * For more, read <https://chrisdone.com/posts/lucid the blog post>
    .
    See the "Lucid" module for more documentation.
category: Web
abi: b2726b103b5fbf7dea8c97972b22cf54
exposed: True
exposed-modules:
    Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs: /usr/lib/ghc-8.4.3/site-local/lucid-2.9.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/lucid-2.9.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/lucid-2.9.10
hs-libraries: HSlucid-2.9.10-Lw86LtstYuwAdYyVyAbwQe
depends:
    base-4.11.1.0 blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    bytestring-0.10.8.2 containers-0.5.11.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt mtl-2.2.2 text-1.2.3.0
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt=a11d1b6072309591a730a4f5ac739aa1
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
haddock-interfaces: /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html: /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lucid-2.9.10-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lucid
version: 2.9.10
id: lucid-2.9.10-Au9vnaY7tsS2I3BvqixZaK
key: lucid-2.9.10-Au9vnaY7tsS2I3BvqixZaK
license: BSD-3-Clause
copyright: 2014-2017 Chris Done
maintainer: chrisdone@gmail.com, oleg.grenrus@iki.fi
author: Chris Done
homepage: https://github.com/chrisdone/lucid
synopsis: Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.
    .
    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)
    .
    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')
    .
    * For more, read <https://chrisdone.com/posts/lucid the blog post>
    .
    See the "Lucid" module for more documentation.
category: Web
abi: e5eb5db2b9a4882288a2e92ecd64bdf1
exposed: True
exposed-modules:
    Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs: /usr/lib/ghc-8.4.3/site-local/lucid-2.9.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/lucid-2.9.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/lucid-2.9.10
hs-libraries: HSlucid-2.9.10-Au9vnaY7tsS2I3BvqixZaK
depends:
    base-4.11.1.0 blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    bytestring-0.10.8.2 containers-0.5.11.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt mtl-2.2.2 text-1.2.3.0
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt=a11d1b6072309591a730a4f5ac739aa1
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
haddock-interfaces: /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html: /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
